summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/buttongroup.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/buttongroup.cpp')
-rw-r--r--kalarm/lib/buttongroup.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kalarm/lib/buttongroup.cpp b/kalarm/lib/buttongroup.cpp
index b448df48a..018640123 100644
--- a/kalarm/lib/buttongroup.cpp
+++ b/kalarm/lib/buttongroup.cpp
@@ -1,5 +1,5 @@
/*
* buttongroup.cpp - QButtonGroup with an extra signal and KDE 2 compatibility
* Program: kalarm
* Copyright (c) 2002, 2004 by David Jarvie <software@astrojar.org.uk>
*
@@ -19,45 +19,45 @@
*/
#include "kalarm.h"
-#include <qlayout.h>
-#include <qbutton.h>
+#include <tqlayout.h>
+#include <tqbutton.h>
#include <kdialog.h>
#include "buttongroup.moc"
-ButtonGroup::ButtonGroup(QWidget* parent, const char* name)
- : QButtonGroup(parent, name)
+ButtonGroup::ButtonGroup(TQWidget* parent, const char* name)
+ : TQButtonGroup(parent, name)
{
- connect(this, SIGNAL(clicked(int)), SIGNAL(buttonSet(int)));
+ connect(this, TQT_SIGNAL(clicked(int)), TQT_SIGNAL(buttonSet(int)));
}
-ButtonGroup::ButtonGroup(const QString& title, QWidget* parent, const char* name)
- : QButtonGroup(title, parent, name)
+ButtonGroup::ButtonGroup(const TQString& title, TQWidget* parent, const char* name)
+ : TQButtonGroup(title, parent, name)
{
- connect(this, SIGNAL(clicked(int)), SIGNAL(buttonSet(int)));
+ connect(this, TQT_SIGNAL(clicked(int)), TQT_SIGNAL(buttonSet(int)));
}
-ButtonGroup::ButtonGroup(int strips, Qt::Orientation orient, QWidget* parent, const char* name)
- : QButtonGroup(strips, orient, parent, name)
+ButtonGroup::ButtonGroup(int strips, Qt::Orientation orient, TQWidget* parent, const char* name)
+ : TQButtonGroup(strips, orient, parent, name)
{
- connect(this, SIGNAL(clicked(int)), SIGNAL(buttonSet(int)));
+ connect(this, TQT_SIGNAL(clicked(int)), TQT_SIGNAL(buttonSet(int)));
}
-ButtonGroup::ButtonGroup(int strips, Qt::Orientation orient, const QString& title, QWidget* parent, const char* name)
- : QButtonGroup(strips, orient, title, parent, name)
+ButtonGroup::ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* parent, const char* name)
+ : TQButtonGroup(strips, orient, title, parent, name)
{
- connect(this, SIGNAL(clicked(int)), SIGNAL(buttonSet(int)));
+ connect(this, TQT_SIGNAL(clicked(int)), TQT_SIGNAL(buttonSet(int)));
}
/******************************************************************************
* Inserts a button in the group.
* This should really be a virtual method...
*/
-int ButtonGroup::insert(QButton* button, int id)
+int ButtonGroup::insert(TQButton* button, int id)
{
- id = QButtonGroup::insert(button, id);
- connect(button, SIGNAL(toggled(bool)), SLOT(slotButtonToggled(bool)));
+ id = TQButtonGroup::insert(button, id);
+ connect(button, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotButtonToggled(bool)));
return id;
}
@@ -1,5 +1,5 @@
/*
- * buttongroup.cpp - QButtonGroup with an extra signal and KDE 2 compatibility
+ * buttongroup.cpp - TQButtonGroup with an extra signal and KDE 2 compatibility
* Program: kalarm
* Copyright (c) 2002, 2004 by David Jarvie <software@astrojar.org.uk>